==> hs-hs-bibutils-4.12_4.tbz: lib/ghc-7.4.1/cabal/hs-bibutils-4.12/register.sh <==
#!/bin/sh
echo 'name: hs-bibutils
version: 4.12
id: hs-bibutils-4.12-2aa31e0d8dabf0bca106f0e6224f7507

license: GPL
copyright:
maintainer: andrea.rossato@unitn.it
stability:
homepage: http://code.haskell.org/hs-bibutils
package-url:
synopsis: Haskell bindings to bibutils, the bibliography
          conversion utilities.
description: Haskell bindings to Chris Putnam'\''s bibutils, a
             library that interconverts between various
             bibliography formats using a common MODS-format
             XML intermediate.
             .
             hs-bibutils is available under the GNU GPL license. See
             the LICENSE file for details.
             .
             For more details about bibutils, please check:
             <http://www.scripps.edu/~cdputnam/software/bibutils/>.
             .
             The original API documentation is available here:
             <http://www.scripps.edu/~cdputnam/software/bibutils/library_specs.html>.
             .
             The package release number refers to the release number of
             the included bibutils library.
category: Text
author: Andrea Rossato
exposed: True
exposed-modules: Text.Bibutils
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/hs-bibutils-4.12
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/hs-bibutils-4.12
              /usr/local/lib
hs-libraries: HShs-bibutils-4.12
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes: bibutils.h
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         syb-0.3.6.1-ad5889c79a555efaeb0cf987ce0538b6
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/hs-bibutils-4.12/html/hs-bibutils.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/hs-bibutils-4.12/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-hs-bibutils-4.17.tbz: lib/ghc-7.4.2/cabal/hs-bibutils-4.17/register.sh <==
#!/bin/sh
echo 'name: hs-bibutils
version: 4.17
id: hs-bibutils-4.17-0b9759dc91f9310a835a3ee78e03b90f

license: GPL
copyright:
maintainer: andrea.rossato@unitn.it
stability:
homepage: http://gorgias.mine.nu/repos/hs-bibutils/
package-url:
synopsis: Haskell bindings to bibutils, the bibliography
          conversion utilities.
description: Haskell bindings to Chris Putnam'\''s bibutils, a
             library that interconverts between various
             bibliography formats using a common MODS-format
             XML intermediate.
             .
             hs-bibutils is available under the GNU GPL license. See
             the LICENSE file for details.
             .
             For more details about bibutils, please check:
             <http://sourceforge.net/p/bibutils/home/Bibutils/>.
             .
             The original API documentation is available here:
             <http://www.scripps.edu/~cdputnam/software/bibutils/library_specs.html>.
             .
             The package release number refers to the release number of
             the included bibutils library.
category: Text
author: Andrea Rossato
exposed: True
exposed-modules: Text.Bibutils
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/hs-bibutils-4.17
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/hs-bibutils-4.17
              /usr/local/lib
hs-libraries: HShs-bibutils-4.17
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes: bibutils.h
depends: base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         syb-0.3.7-a269c050536d4890f37a20513844e800
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/hs-bibutils-4.17/html/hs-bibutils.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/hs-bibutils-4.17/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
